==> jc-1.4.0.tar.gz: polyglot/visit/CFGBuilder__24EdgeKeyTermPair.h <==
// public class polyglot.visit.CFGBuilder$EdgeKeyTermPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bc2dbb02a5703d3 polyglot_visit_CFGBuilder__24EdgeKeyTermPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_CFGBuilder__24EdgeKeyTermPair_H_
#define _JC_polyglot_visit_CFGBuilder__24EdgeKeyTermPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object;

// Typedefs
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object;

typedef const struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods;
typedef const struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable;
typedef const struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype;

// Constructors
extern void _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$method$_init$36f2ba2beb7bf719(_jc_env *, struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods {
};

// Vtable
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods	polyglot_visit_CFGBuilder__24EdgeKeyTermPair;
};

// Vtype
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype {
	_jc_type			type;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs {
	struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	*edgeKey;
	struct _jc_object	*term;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs {
    _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs	polyglot_visit_CFGBuilder__24EdgeKeyTermPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs	polyglot_visit_CFGBuilder__24EdgeKeyTermPair;
};

// Object instance structure
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object {
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype	*vtype;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_CFGBuilder__24EdgeKeyTermPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$class_object;

#endif	/* _JC_polyglot_visit_CFGBuilder__24EdgeKeyTermPair_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/CFGBuilder__24EdgeKeyTermPair.h <==
// public class polyglot.visit.CFGBuilder$EdgeKeyTermPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bc2dbb02a5703d3 polyglot_visit_CFGBuilder__24EdgeKeyTermPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_CFGBuilder__24EdgeKeyTermPair_H_
#define _JC_polyglot_visit_CFGBuilder__24EdgeKeyTermPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object;

// Typedefs
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs;
typedef struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object;

typedef const struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods;
typedef const struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable;
typedef const struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype;

// Constructors
extern void _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$method$_init$36f2ba2beb7bf719(_jc_env *, struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods {
};

// Vtable
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vmethods	polyglot_visit_CFGBuilder__24EdgeKeyTermPair;
};

// Vtype
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype {
	_jc_type			type;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs {
	struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	*edgeKey;
	struct _jc_object	*term;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs {
    _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_refs	polyglot_visit_CFGBuilder__24EdgeKeyTermPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$sub_nonrefs	polyglot_visit_CFGBuilder__24EdgeKeyTermPair;
};

// Object instance structure
struct _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$object {
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype	*vtype;
	_jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$vtype _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_CFGBuilder__24EdgeKeyTermPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_CFGBuilder__24EdgeKeyTermPair$class_object;

#endif	/* _JC_polyglot_visit_CFGBuilder__24EdgeKeyTermPair_H_ */
